@@ -1,4 +1,7 @@
-from typing import List, Union, Dict
+from typing import Dict, List, Union
+
+import pandas as pd
+from tqdm import tqdm
 
 import arxiv
 
@@ -9,6 +12,7 @@ arxiv_field_mapper = {
     "published": "date",
     "journal_ref": "journal",
     "summary": "abstract",
+    "entry_id": "doi",
 }
 
 # Authors, date, and journal fields need specific processing
@@ -16,6 +20,7 @@ process_fields = {
     "authors": lambda authors: ", ".join([a.name for a in authors]),
     "date": lambda date: date.strftime("%Y-%m-%d"),
     "journal": lambda j: j if j is not None else "",
+    "doi": lambda entry_id: f"10.48550/arXiv.{entry_id.split('/')[-1].split('v')[0]}",
 }
 
 
@@ -25,7 +30,7 @@ def get_arxiv_papers(
     max_results: int = 99999,
     client_options: Dict = {"num_retries": 10},
     search_options: Dict = dict(),
-):
+) -> pd.DataFrame:
     """
     Performs arxiv API request of a given query and returns list of papers with
     fields as desired.
@@ -42,23 +47,25 @@ def get_arxiv_papers(
             id_list (List), sort_by, or sort_order.
 
     Returns:
-        list of dicts. One dict per paper.
+        pd.DataFrame: One row per paper.
 
     """
     client = arxiv.Client(**client_options)
     search = arxiv.Search(query=query, max_results=max_results, **search_options)
     results = client.results(search)
 
-    processed = [
-        {
-            arxiv_field_mapper.get(key, key): process_fields.get(
-                arxiv_field_mapper.get(key, key), lambda x: x
-            )(value)
-            for key, value in vars(paper).items()
-            if arxiv_field_mapper.get(key, key) in fields
-        }
-        for paper in results
-    ]
+    processed = pd.DataFrame(
+        [
+            {
+                arxiv_field_mapper.get(key, key): process_fields.get(
+                    arxiv_field_mapper.get(key, key), lambda x: x
+                )(value)
+                for key, value in vars(paper).items()
+                if arxiv_field_mapper.get(key, key) in fields and key != "doi"
+            }
+            for paper in tqdm(results, desc=f"Processing {query}")
+        ]
+    )
     return processed
 
 
@@ -67,7 +74,7 @@ def get_and_dump_arxiv_papers(
     output_filepath: str,
     fields: List = ["title", "authors", "date", "abstract", "journal", "doi"],
     *args,
-    **kwargs
+    **kwargs,
 ):
     """
     Combines get_arxiv_papers and dump_papers.
